@@ -10,7 +10,7 @@ BEGIN {
   *_CAN_GOTO_VERSION = ($] >= 5.010000) ? sub(){1} : sub(){0};
 }
 
-our $VERSION = '2.000001';
+our $VERSION = '2.000002';
 $VERSION = eval $VERSION;
 
 our @WARNING_CATEGORIES = grep { exists $warnings::Offsets{$_} } qw(
@@ -106,7 +106,7 @@ our $Smells_Like_VCS;
 
 sub import {
   my $class = shift;
-  my %opts = ref $_[0] ? %{$_[0]} : @_;
+  my %opts = @_ == 1 ? %{$_[0]} : @_;
   if (!exists $opts{version}) {
     $opts{version}
       = exists $^H{strictures_enable} ? delete $^H{strictures_enable}
